@@ -1,6 +1,6 @@
 package NetHack::Item::Food;
 {
-  $NetHack::Item::Food::VERSION = '0.17';
+  $NetHack::Item::Food::VERSION = '0.18';
 }
 use Moose;
 extends 'NetHack::Item';
@@ -30,6 +30,11 @@ with 'NetHack::Item::Role::IncorporatesStats' => {
     stat      => 'laid',
 };
 
+sub nutrition_per_weight {
+    my $self = shift;
+    return $self->nutrition / $self->weight;
+}
+
 __PACKAGE__->meta->install_spoilers(qw/nutrition time vegan vegetarian/);
 
 __PACKAGE__->meta->make_immutable;
