@@ -1,6 +1,6 @@
 package NetHack::Item::Spoiler::Other;
 {
-  $NetHack::Item::Spoiler::Other::VERSION = '0.17';
+  $NetHack::Item::Spoiler::Other::VERSION = '0.18';
 }
 use strict;
 use warnings;
@@ -11,14 +11,6 @@ use constant type => 'other';
 
 sub _list {
     my $others = {
-        'gold piece' => {
-            price  => 1,
-            weight => 0.01,
-            glyph  => '$',
-            plural => 'gold pieces',
-            stackable  => 1,
-            material => 'gold',
-        },
         'boulder' => {
             price     => 0,
             weight    => 6000,
